@@ -1,6 +1,7 @@
 package Lab::Moose::Connection::LinuxGPIB;
+$Lab::Moose::Connection::LinuxGPIB::VERSION = '3.600';
 #ABSTRACT: Connection back end to the LinuxGpib library and kernel drivers
-$Lab::Moose::Connection::LinuxGPIB::VERSION = '3.554';
+
 
 use 5.010;
 
@@ -9,7 +10,7 @@ use MooseX::Params::Validate;
 use Moose::Util::TypeConstraints qw(enum);
 use Carp;
 
-use Lab::Moose::Instrument qw/timeout_param/;
+use Lab::Moose::Instrument qw/timeout_param read_length_param/;
 
 use Time::HiRes qw/gettimeofday tv_interval/;
 
@@ -26,7 +27,6 @@ use LinuxGpib qw/
     /;
 
 
-
 has pad => (
     is        => 'ro',
     isa       => enum( [ ( 0 .. 30 ) ] ),
@@ -112,12 +112,13 @@ sub BUILD {
 
 
 sub Read {
-    my ( $self, %arg ) = validated_hash(
+    my ( $self, %args ) = validated_hash(
         \@_,
         timeout_param,
+        read_length_param,
     );
 
-    my $timeout = $self->_timeout_arg(%arg);
+    my $timeout = $self->_timeout_arg(%args);
 
     my $result_string = "";
 
@@ -133,7 +134,7 @@ sub Read {
         if ( $elapsed_time > $self->current_timeout() ) {
             croak(
                 "timeout in Read with args:\n",
-                Dump( \%arg )
+                Dump( \%args )
             );
         }
 
@@ -147,7 +148,7 @@ sub Read {
 
         $self->_croak_on_err(
             ibsta => $ibsta,
-            name  => "ibrd with args:\n" . Dump( \%arg )
+            name  => "ibrd with args:\n" . Dump( \%args )
         );
 
         $result_string .= $buffer;
@@ -163,13 +164,13 @@ sub Read {
 
 
 sub Write {
-    my ( $self, %arg ) = validated_hash(
+    my ( $self, %args ) = validated_hash(
         \@_,
         timeout_param,
         command => { isa => 'Str' },
     );
-    my $command = $arg{command};
-    my $timeout = $self->_timeout_arg(%arg);
+    my $command = $args{command};
+    my $timeout = $self->_timeout_arg(%args);
 
     $self->_set_timeout( timeout => $timeout );
 
@@ -181,18 +182,18 @@ sub Write {
 
     $self->_croak_on_err(
         ibsta => $ibsta,
-        name  => "ibwrt with args:\n" . Dump( \%arg )
+        name  => "ibwrt with args:\n" . Dump( \%args )
     );
 }
 
 
 sub Clear {
-    my ( $self, %arg ) = validated_hash(
+    my ( $self, %args ) = validated_hash(
         \@_,
         timeout_param,
     );
 
-    my $timeout = $self->_timeout_arg(%arg);
+    my $timeout = $self->_timeout_arg(%args);
 
     $self->_set_timeout( timeout => $timeout );
 
@@ -203,12 +204,12 @@ sub Clear {
 }
 
 sub _set_timeout {
-    my ( $self, %arg ) = validated_hash(
+    my ( $self, %args ) = validated_hash(
         \@_,
         timeout => { isa => 'Num' },
     );
 
-    my $timeout             = $arg{timeout};
+    my $timeout             = $args{timeout};
     my $ibtmo_value         = _timeout_to_ibtmo($timeout);
     my $current_timeout     = $self->current_timeout();
     my $current_ibtmo_value = _timeout_to_ibtmo($current_timeout);
@@ -222,13 +223,13 @@ sub _set_timeout {
 }
 
 sub _croak_on_err {
-    my ( $self, %arg ) = validated_hash(
+    my ( $self, %args ) = validated_hash(
         \@_,
         ibsta => { isa => 'Int' },
         name  => { isa => 'Str', optional => 1 },
     );
-    my $ibsta = $arg{ibsta};
-    my $name  = $arg{name};
+    my $ibsta = $args{ibsta};
+    my $name  = $args{name};
     my $hash  = _ibsta_to_hash($ibsta);
     if ( $hash->{ERR} ) {
         croak(
@@ -299,7 +300,7 @@ Lab::Moose::Connection::LinuxGPIB - Connection back end to the LinuxGpib library
 
 =head1 VERSION
 
-version 3.554
+version 3.600
 
 =head1 SYNOPSIS
 
