@@ -1,6 +1,7 @@
 package Lab::Moose::Instrument::SCPIBlock;
+$Lab::Moose::Instrument::SCPIBlock::VERSION = '3.600';
 #ABSTRACT: Role for handling SCPI/IEEE 488.2 block data
-$Lab::Moose::Instrument::SCPIBlock::VERSION = '3.554';
+
 use Moose::Role;
 use MooseX::Params::Validate;
 
@@ -16,6 +17,24 @@ with qw/
     /;
 
 
+sub block_length {
+    my $self = shift;
+    my ( $num_points, $precision ) = validated_list(
+        \@_,
+        num_points => { isa => 'Int' },
+        precision_param(),
+    );
+
+    my $point_length
+        = $precision eq 'single' ? 4
+        : $precision eq 'double' ? 8
+        :                          croak("unknown precision $precision");
+
+    my $read_length = $num_points * $point_length;
+    $read_length += length("#d") + length($read_length) + length("\n");
+    return $read_length;
+}
+
 sub block_to_array {
     my ( $self, %args ) = validated_hash(
         \@_,
@@ -81,7 +100,7 @@ Lab::Moose::Instrument::SCPIBlock - Role for handling SCPI/IEEE 488.2 block data
 
 =head1 VERSION
 
-version 3.554
+version 3.600
 
 =head1 DESCRIPTION
 
@@ -102,6 +121,15 @@ See "8.7.9 <DEFINITE LENGTH ARBITRARY BLOCK RESPONSE DATA>" in IEEE 488.2.
 Convert block data to arrayref, where the binary block holds floating point
 values in native byte-order.
 
+=head2 block_length
+
+ my $read_length = $self->block_length(
+     num_points => $num_points,
+     precision => $precision
+ );
+
+Calulate block length for use in C<read_length> parameter.
+
 =head2 set_data_format_precision
 
  $self->set_data_format_precision( precision => 'double' );
@@ -113,7 +141,7 @@ Set used floating point type. Has to be 'single' (default) or 'double'.
 This software is copyright (c) 2017 by the Lab::Measurement team; in detail:
 
   Copyright 2016       Simon Reinhardt
-            2017       Andreas K. Huettel
+            2017       Andreas K. Huettel, Simon Reinhardt
 
 
 This is free software; you can redistribute it and/or modify it under
